import request from '@/config/axios'

// 资金拨付流程表	 VO
export interface DisbursementVO {
  id: number // 资金拨付表单主键
  userId: number // 申请人的用户编号
  reason: string // 申请原因
  processInstanceId: string // 流程实例的编号
  file: string // 文件
  type: number // 申请类型
  funding: number // 申请总金额
  status: number // 审批结果
  specialLoansFile: string // 专项借款申请材料
  itemName: string // 项目名称
  itemType: number // 项目类型
  itemBelong: number // 项目归属（上级目录）
  itemShp: string // 项目相关shp上传（保存url，可null）
  itemImage: string // 项目相关佐证材料（图片，如施工图）
  fundingApplicationFile: string // 资金申请材料
  itemDisbursementStatus: number // 项目拨付结果（状态值）
  initialShotPosition: string // 初始镜头位置
  projectDetails: string // 项目详情
  projectProgress: number // 项目进度
  projectScope: string // 项目范围
  projectBudget: number // 项目预算
  projectLeader: string // 项目负责人
  startDate: Date // 项目开始时间
  estimatedEndDate: Date // 项目预计结束时间
  actualEndDate: Date // 项目实际结束时间
}

// 资金拨付流程表	 API
export const DisbursementApi = {
  // 查询资金拨付流程表	分页
  getDisbursementPage: async (params: any) => {
    return await request.get({ url: `/bpm/disbursement/page`, params })
  },

  // 查询资金拨付流程表	详情
  getDisbursement: async (id: number) => {
    return await request.get({ url: `/bpm/disbursement/get?id=` + id })
  },

  // 新增资金拨付流程表	
  createDisbursement: async (data: DisbursementVO) => {
    return await request.post({ url: `/bpm/disbursement/create`, data })
  },

  // 修改资金拨付流程表	
  updateDisbursement: async (data: DisbursementVO) => {
    return await request.put({ url: `/bpm/disbursement/update`, data })
  },

  // 删除资金拨付流程表	
  deleteDisbursement: async (id: number) => {
    return await request.delete({ url: `/bpm/disbursement/delete?id=` + id })
  },

  // 导出资金拨付流程表	 Excel
  exportDisbursement: async (params) => {
    return await request.download({ url: `/bpm/disbursement/export-excel`, params })
  },

  setAuthority: async (data: any) => {
    return await request.post({ url: `/bpm/disbursement/set-authority`, data })
  },

  getAuthorityRole: async (id: number) => {
    return await request.get({ url: `/bpm/disbursement/get-authority-role?id=` + id })
  },

  getAuthorityUser: async (id: number) => {
    return await request.get({ url: `/bpm/disbursement/get-authority-user?id=` + id })
  },

  getTeamMember: async (params: any) => {
    return await request.get({ url: `/bpm/disbursement/get-member`, params })
  },
  addTeamMember: async (data: any) => {
    return await request.post({ url: `/bpm/disbursement/add-member` , data })
  },
  deleteTeamMember: async (id: any, userId: any) => {
    return await request.delete({ url: `/bpm/disbursement/delete-member?id=` + id + "&userId=" + userId  })
  },
  // 修改资金拨付流程表
  updateTeamMember: async (data: any) => {
    // console.log(data)
    return await request.put({ url: `/bpm/disbursement/update-member`, data })
  },

}
