import request from '@/config/axios'

// 图层表单 VO
export interface GisFormVO {
  id: number // 编号
  type: number // 图层数据类型
  name: string // 地理实体名
  parentId: number // 父级编号
  seq: number // 排序
  fileFormat: string // 文件格式
  urlAddress: string // url地址
  fileAddress: string // 文件地址
  key: string // API key
  rgb: number // 图层颜色
  acquisitionDate: Date // 数据获取日期
  description: string // 数据描述或摘要
  shpId: number // 图层关联
  file: string // 文件上传
  shpName: string // shp表名
}

// 图层表单 API
export const GisFormApi = {
  // 查询图层表单列表
  getGisFormList: async (params) => {
    return await request.get({ url: `/layer/gis-form/list`, params })
  },

  // 查询图层表单详情
  getGisForm: async (id: number) => {
    return await request.get({ url: `/layer/gis-form/get?id=` + id })
  },

  // 新增图层表单
  createGisForm: async (data: GisFormVO) => {
    return await request.post({ url: `/layer/gis-form/create`, data })
  },

  // 修改图层表单
  updateGisForm: async (data: GisFormVO) => {
    return await request.put({ url: `/layer/gis-form/update`, data })
  },

  // 删除图层表单
  deleteGisForm: async (id: number) => {
    return await request.delete({ url: `/layer/gis-form/delete?id=` + id })
  },

  // 导出图层表单 Excel
  exportGisForm: async (params) => {
    return await request.download({ url: `/layer/gis-form/export-excel`, params })
  },
}
