import request from '@/config/axios'

// 模型管理 VO
export interface TwinModelsVO {
  id: number // 编号
  modelName: string // 模型名称
  modelPath: string // 模型路径
  imagePath: string // 模型图片路径
  thumbnailPath: string // 缩略图路径
  description: string // 模型描述
  modelType: number // 模型类型
  status: number // 模型状态
  tenantId: number // 是否为公共模型
}

// 模型管理 API
export const TwinModelsApi = {
  // 查询模型管理分页
  getTwinModelsPage: async (params: any) => {
    return await request.get({ url: `/gismodel/twin-models/pageModel`, params })
  },

  // 查询模型管理详情
  getTwinModels: async (id: number) => {
    return await request.get({ url: `/gismodel/twin-models/getModels?id=` + id })
  },

  // 新增模型管理
  createTwinModels: async (data: TwinModelsVO) => {
    return await request.post({ url: `/gismodel/twin-models/create`, data })
  },

  // 修改模型管理
  updateTwinModels: async (data: TwinModelsVO) => {
    return await request.put({ url: `/gismodel/twin-models/update`, data })
  },

  // 删除模型管理
  deleteTwinModels: async (id: number) => {
    return await request.delete({ url: `/gismodel/twin-models/delete?id=` + id })
  },

  // 导出模型管理 Excel
  exportTwinModels: async (params) => {
    return await request.download({ url: `/gismodel/twin-models/export-modelExcel`, params })
  },
}
