import request from '@/config/axios'

// 项目信息表 VO
export interface VisualizeMessageVO {
  id: number // 编号
  parentId: number // 父ID
  associateLayerName: string // 关联图层名
  associateLayerId: number // 关联图层ID
  placeName: string // 地名
  sort: number // 排序
  itemName: string // 项目名称
  itemId: number // 项目编号
  implementedBy: string // 执行单位
  itemDescribe: string // 项目描述
  itemFile: string // 项目相关附件
  itemUserName: string // 项目负责人
  itemBudget: number // 项目总预算
  allocatedFunds: number // 已经分配资金
  itemGetFunds: number // 项目获得资金
  itemStartTime: Date // 项目开始时间
  itemEstimateEndTime: Date // 项目预估结束时间
  itemActualEndTime: Date // 项目实际结束时间
  status: number // 项目状态
  itemInfluenceRange: string // 项目影响范围
  itemRiskDescription: string // 项目风险描述
  planForUse: string // 规划用途
  placeId: number // 地块编号
  placeType: number // 地块类型
  propertyOwnerNameOrUnitName: string // 产权人或单位名
  phone: string // 联系方式
  titleDeedNumber: number // 产权证编号
  address: string // 详细地址
  layerColor: string // 图层颜色
  propertyValuation: string // 产权估值
  propertyRightsIntroduction: string // 产权简介
  useType: number // 使用权类型
  useStartTime: Date // 使用权开始时间
  useEndTime: Date // 使用权结束时间
  titleProceedingsRecords: string // 产权法律诉讼记录
  propertyTransactionsInfo: string // 产权交易信息
  mortgageSituation: string // 抵押情况
  propertyOwnerImage: string // 产权人照片上传
  realImage: string // 实景照片上传
  imageDescription: string // 图片信息描述
}

// 项目信息表 API
export const VisualizeMessageApi = {
  // 查询项目信息表分页
  getVisualizeMessagePage: async (params: any) => {
    return await request.get({ url: `/layer/visualize-message/page`, params })
  },

  // 查询项目信息表详情
  getVisualizeMessage: async (id: number) => {
    return await request.get({ url: `/layer/visualize-message/get?id=` + id })
  },

  // 新增项目信息表
  createVisualizeMessage: async (data: VisualizeMessageVO) => {
    return await request.post({ url: `/layer/visualize-message/create`, data })
  },

  // 修改项目信息表
  updateVisualizeMessage: async (data: VisualizeMessageVO) => {
    return await request.put({ url: `/layer/visualize-message/update`, data })
  },

  // 删除项目信息表
  deleteVisualizeMessage: async (id: number) => {
    return await request.delete({ url: `/layer/visualize-message/delete?id=` + id })
  },

  // 导出项目信息表 Excel
  exportVisualizeMessage: async (params) => {
    return await request.download({ url: `/layer/visualize-message/export-excel`, params })
  },
}
